# Pascal VOC Tools

This package includes some tools about pascal voc format dataset like read xml, write xml, resize image.

[![Documentation Status](https://readthedocs.org/projects/pascal-voc-tools/badge/?version=latest)](https://pascal-voc-tools.readthedocs.io/en/latest/?badge=latest)

# Functions
- annotations file laod, edit and save;
- dataset resize;
- dataset argument(function from [link](https://github.com/Paperspace/DataAugmentationForObjectDetection));
- darknet anchors k-means;

# Install
```bash
pip install pascal-voc-tools
```
